resource "aws_cloudwatch_metric_alarm" "sqs_messages_visible_alarm" {
  for_each = toset(local.sqs)
  alarm_name          = "${each.value}-ApproximateNumberOfMessagesVisible"
  comparison_operator = "GreaterThanThreshold"
  evaluation_periods  = "10"
  alarm_description = "Number of messages available in queue in 10 minutes"
  metric_name = "ApproximateNumberOfMessagesVisible"
  period = 60
  actions_enabled = true
  statistic = "SampleCount"
  threshold = "500"
  dimensions = {
    QueueName = each.value
  }
  alarm_actions = [var.SNS_TOPIC_ARN]
  ok_actions = [var.SNS_TOPIC_ARN]
  unit = "Count"
  tags = local.tags
  namespace = "AWS/SQS"
}

resource "aws_cloudwatch_metric_alarm" "sqs_dlq_messages_visible_alarm" {
  for_each = toset(local.sqs_dlq)
  alarm_name          = "${each.value}-ApproximateNumberOfMessagesVisible"
  comparison_operator = "GreaterThanThreshold"
  evaluation_periods  = "10"
  alarm_description = "Number of messages available in queue in 10 minutes"
  metric_name = "ApproximateNumberOfMessagesVisible"
  period = 60
  actions_enabled = true
  statistic = "SampleCount"
  threshold = "0"
  dimensions = {
    QueueName = each.value
  }
  alarm_actions = [var.SNS_TOPIC_ARN]
  ok_actions = [var.SNS_TOPIC_ARN]
  unit = "Count"
  tags = local.tags
  namespace = "AWS/SQS"
}