#!/bin/bash

source /scripts/utils.sh
source /scripts/terraform.sh

export TF_VAR_ENVIRONMENT=${env}
export TF_VAR_SNS_TOPIC_ARN=$(echo $vars | jq .SNS_TOPIC_ARN | tr '"' ' ' | xargs)

echo "${TF_VAR_ENVIRONMENT} and ${TF_VAR_SNS_TOPIC_ARN}"

cd /terraform/mcs2-cloudwatch-alerts || exit 1
ls
if [[ ${TF_VAR_ENVIRONMENT} == "kcdev01" ]]; then
  print_header "Terraform Init"
  run_cmd terraform init -backend-config="bucket=${tfBucketName}" -backend-config="key=${tfBucketKey}" -backend-config="region=${awsDefaultRegion}" -lock=false -plugin-dir=/terraform/.terraform/providers/ $@

  export TF_X_CONCISE_DIFF=0

  print_header "Terraform Plan"
  run_cmd terraform plan "${optTfVar}" --out plan.out --lock=false $@
  run_cmd terraform show plan.out \>plan.txt
  run_cmd terraform show -json plan.out \> terraform-show.json

  unset TF_X_CONCISE_DIFF
  print_header "Terraform Apply"

  if [ ! -f plan.out ]; then
    cprint "Error: failed to find Terraform plan.out" red
    exit 1
  else
    cprint "Found Terraform plan file"
    run_cmd terraform show plan.out
  fi

  ## apply plan.out
  run_cmd terraform apply -lock=false $@ plan.out

else
  echo "Workspace not configured"
fi